@@ -2,4 +2,6 @@ from dnastack.client import *
 from .cli_config import commands as config_commands
 from .dataconnect import commands as dataconnect_commands
 from .files import commands as file_commands
+from .auth import commands as auth_commands
 from .collections import commands as collections_commands
+from .wes import commands as wes_commands
