@@ -18,11 +18,14 @@ def get_config(ctx, var_name, val_type=None, do_assert=False):
 
 def set_config(ctx, var_name: str, value):
     if type(value) == dict:
-        ctx.obj[var_name] = {}
+        if not (var_name in ctx.obj.keys() and type(ctx.obj[var_name]) == dict):
+            ctx.obj[var_name] = {}
         for key, val in zip(value.keys(), value.values()):
             ctx.obj[var_name][key] = val
-
-    set_configs(ctx, [var_name], [value])
+        with open(config_file_path, "w") as config_file:
+            yaml.dump(ctx.obj, config_file)
+    else:
+        set_configs(ctx, [var_name], [value])
 
 
 def set_configs(ctx, var_names: list, values: list):
@@ -74,3 +77,18 @@ def assert_config_key(key):
         for key in ACCEPTED_CONFIG_KEYS:
             click.secho(f"\t{key}", fg="red")
         sys.exit(1)
+
+
+def get_auth_params(ctx, do_assert=False):
+    auth_params = {
+        "wallet_uri": get_config(ctx=ctx, var_name="wallet-url", do_assert=do_assert),
+        "redirect_uri": get_config(
+            ctx=ctx, var_name="client-redirect-uri", do_assert=do_assert
+        ),
+        "client_id": get_config(ctx=ctx, var_name="client-id", do_assert=do_assert),
+        "client_secret": get_config(
+            ctx=ctx, var_name="client-secret", do_assert=do_assert
+        ),
+    }
+
+    return auth_params
