@@ -50,7 +50,6 @@ def is_drs_url(url):
 def get_object_info_url_from_drs(url):
     drs_host = re.search(r"(?<=drs://)([^/])+(?=/.*)", url)
     if not drs_host:
-        click.secho(f"Could not get drs host from url {url}\n", fg="red")
         raise Exception(f"Could not get drs host from url {url}")
     object_url = f"https://{drs_host.group(0)}/ga4gh/drs/v1/"
     return object_url, drs_host
@@ -61,23 +60,23 @@ def get_object_id_from_drs(url):
     if object_id:
         return object_id.group(0)
     else:
-        click.secho(f"Could not get drs object id from url {url}\n", fg="red")
         raise Exception(f"Could not get drs object id from url {url}")
 
 
-def exit_download(url, code, exit_codes):
+def exit_download(url: str, code: int, message: str = "", exit_codes: dict = None):
     if exit_codes is not None:
         exit_code_lock.acquire()
-        exit_codes[url] = code
+        exit_codes[url] = (code, message)
         exit_code_lock.release()
 
 
 def download_file(
-    url,
-    output_dir,
+    url: str,
+    output_dir: str,
     oauth_token: Optional[dict] = None,
+    quiet: bool = False,
     out: Optional[list] = None,
-    exit_codes=None,
+    exit_codes: Optional[dict] = None,
 ):
 
     http = urllib3.PoolManager()
@@ -95,35 +94,40 @@ def download_file(
             object_info = drs_client.get_object_info(object_id)
         except HTTPError as e:
             if e.response.status_code == 404:
-                click.secho(f"DRS object with id {object_id} does not exist", fg="red")
+                error_msg = f"DRS object at url [{url}] does not exist"
             elif e.response.status_code == 403:
-                click.secho("Access Denied", fg="red")
+                error_msg = "Access Denied"
             else:
-                click.secho(
-                    "There was an error getting object info from the DRS Client",
-                    fg="red",
-                )
-                http.clear()
-                exit_download(url, 1, exit_codes)
-                return
+                error_msg = "There was an error getting object info from the DRS Client"
+            http.clear()
+            exit_download(url, 1, error_msg, exit_codes)
+            return
         except Exception as e:
             http.clear()
-            exit_download(url, 1, exit_codes)
+            exit_download(
+                url,
+                1,
+                f"There was an error getting object info from the DRS Client: {e}",
+                exit_codes,
+            )
             return
 
         if "access_methods" in object_info.keys():
             for access_method in object_info["access_methods"][0]:
                 if access_method.get("access_id", None):
                     if access_method["access_id"] in signed_access_ids:
-                        click.echo("found signed access_id @ access_method level")
                         try:
                             object_access = drs_client.get_object_access(
                                 object_id, access_method["access_id"]
                             )
                         except HTTPError as e:
-                            click.echo(e)
                             http.clear()
-                            exit_download(url, 1, exit_codes)
+                            exit_download(
+                                url,
+                                1,
+                                f"Error determining access method: {e}",
+                                exit_codes,
+                            )
                         download_url = object_access["url"]
                         break
 
@@ -135,17 +139,17 @@ def download_file(
         else:
             return  # next page token, just return
     else:
-        click.secho(f"[{url}] is not a valid DRS url", fg="red")
         http.clear()
-        exit_download(url, 1, exit_codes)
+        exit_download(url, 1, f"[{url}] is not a valid DRS url", exit_codes)
         return
 
     try:
         download_stream = http.request("GET", download_url, preload_content=False)
-    except:
-        click.secho("There was an error downloading " + download_url, fg="red")
+    except Exception as e:
         http.clear()
-        exit_download(url, 1, exit_codes)
+        exit_download(
+            url, 1, f"There was an error downloading [{download_url}] : {e}", exit_codes
+        )
         return
 
     if out is not None:
@@ -157,20 +161,27 @@ def download_file(
     else:
         with open(f"{output_dir}/{download_file}", "wb+") as dest:
             stream_size = int(download_stream.headers["Content-Length"])
-            click.echo(f"Downloading {url} into {output_dir}/{download_file}")
             file_stream = download_stream.stream(chunk_size)
-            with click.progressbar(length=stream_size, color=True) as download_progress:
+            if not quiet:
+                click.echo(f"Downloading {url} into {output_dir}/{download_file}")
+                with click.progressbar(
+                    length=stream_size, color=True
+                ) as download_progress:
+                    for chunk in file_stream:
+                        dest.write(chunk)
+                        download_progress.update(chunk_size)
+            else:
                 for chunk in file_stream:
                     dest.write(chunk)
-                    download_progress.update(chunk_size)
     http.clear()
-    exit_download(url, 0, exit_codes)
+    exit_download(url, 0, "Download Successful", exit_codes)
 
 
 def download_files(
     urls,
     output_dir=downloads_directory,
     oauth_token: Optional[dict] = None,
+    quiet: bool = False,
     out=None,
 ):
     download_threads = []
@@ -185,6 +196,7 @@ def download_files(
                 url,
                 output_dir,
                 oauth_token,
+                quiet=quiet,
                 out=out,
                 exit_codes=exit_codes,
             ),
@@ -198,6 +210,13 @@ def download_files(
         thread.join()
 
     # at least one download failed, raise an exception
-    failed_downloads = [url for url, code in exit_codes.items() if code != 0]
+    failed_downloads = [
+        {"url": url, "code": result[0], "message": result[1]}
+        for url, result in exit_codes.items()
+        if result[0] != 0
+    ]
     if len(failed_downloads) > 0:
-        raise Exception(f"One or more downloads failed: [{','.join(failed_downloads)}]")
+        error_msg = f"One or more downloads failed:\n"
+        for failure in failed_downloads:
+            error_msg += f"{failure['url']} failed with code {failure['code']}: {failure['message']}\n"
+        raise Exception(error_msg)
