@@ -159,3 +159,7 @@ TEST_WDL_TAG_CONTENTS = """{
 TEST_WDL_ENGINE_PARAM_CONTENTS = """{
   "read_from_cache":"true"
 }"""
+
+TEST_WDL_MULTI_MAIN = "./tests/cli/files/main.wdl"
+TEST_WDL_MULTI_GREETING = "./tests/cli/files/greeting.wdl"
+TEST_WDL_MULTI_FAREWELL = "./tests/cli/files/farewell.wdl"
