@@ -42,6 +42,68 @@ class TestCliWesRunsCommand(unittest.TestCase):
     def test_wes_runs_execute(self):
         self.__execute_workflow()
 
+    def test_wes_runs_execute_multiple_attachments(self):
+        with open(TEST_WDL_MULTI_GREETING, "r") as main_wdl:
+            wdl_main_file_path = self.__create_file("main.wdl", main_wdl.read())
+
+        with open(TEST_WDL_MULTI_GREETING, "r") as greeting_wdl:
+            wdl_greeting_attachment_file = self.__create_file(
+                "greeting.wdl", greeting_wdl.read()
+            )
+
+        with open(TEST_WDL_MULTI_FAREWELL, "r") as farewell_wdl:
+            wdl_farewell_attachment_file = self.__create_file(
+                "farewell.wdl", farewell_wdl.read()
+            )
+
+        wdl_input_param_file_path = self.__create_file(
+            "input.json", TEST_WDL_INPUT_PARAM_CONTENTS
+        )
+        wdl_engine_param_file_path = self.__create_file(
+            "engine.json", TEST_WDL_ENGINE_PARAM_CONTENTS
+        )
+        wdl_tag_file_path = self.__create_file("tag.json", TEST_WDL_TAG_CONTENTS)
+        result = self.runner.invoke(
+            dnastack_cli.dnastack,
+            [
+                "wes",
+                "runs",
+                "execute",
+                "--workflow-url",
+                "main.wdl",
+                "--attachment",
+                wdl_main_file_path,
+                "--attachment",
+                wdl_greeting_attachment_file,
+                "--attachment",
+                wdl_farewell_attachment_file,
+                "--inputs-file",
+                wdl_input_param_file_path,
+                "--engine-parameters-file",
+                wdl_engine_param_file_path,
+                "--tags-file",
+                wdl_tag_file_path,
+            ],
+        )
+
+        self.assertEqual(
+            result.exit_code,
+            0,
+            msg=f"wes runs execute failed with code {result.exit_code} ({result.output})",
+        )
+
+        result_objects = json.loads(result.output)
+        assert_has_property(self, result_objects, "run_id")
+
+        os.remove(wdl_main_file_path)
+        os.remove(wdl_greeting_attachment_file)
+        os.remove(wdl_farewell_attachment_file)
+        os.remove(wdl_input_param_file_path)
+        os.remove(wdl_engine_param_file_path)
+        os.remove(wdl_tag_file_path)
+
+        return result_objects
+
     def test_wes_runs_list(self):
         self.__execute_workflow()
         self.__execute_workflow()
@@ -150,7 +212,7 @@ class TestCliWesRunsCommand(unittest.TestCase):
             ],
         )
 
-        self.assertTrue(result.output == "Hello World, my name is Patrick!\n\n")
+        self.assertEqual(result.output, "Hello World, my name is Patrick!\n\n")
         self.assertEqual(result.exit_code, 0)
 
         result = self.runner.invoke(
@@ -168,7 +230,7 @@ class TestCliWesRunsCommand(unittest.TestCase):
             ],
         )
 
-        self.assertTrue(result.output == "Hello World, my name is Patrick!\n\n")
+        self.assertEqual(result.output, "Hello World, my name is Patrick!\n\n")
         self.assertEqual(result.exit_code, 0)
 
         result = self.runner.invoke(
@@ -186,7 +248,7 @@ class TestCliWesRunsCommand(unittest.TestCase):
             ],
         )
 
-        self.assertTrue(result.output == "Hello World, my name is Patrick!\n\n")
+        self.assertEqual(result.output, "Hello World, my name is Patrick!\n\n")
         self.assertEqual(result.exit_code, 0)
 
     @staticmethod
@@ -204,7 +266,6 @@ class TestCliWesRunsCommand(unittest.TestCase):
             "engine.json", TEST_WDL_ENGINE_PARAM_CONTENTS
         )
         wdl_tag_file_path = self.__create_file("tag.json", TEST_WDL_TAG_CONTENTS)
-
         result = self.runner.invoke(
             dnastack_cli.dnastack,
             [
@@ -224,9 +285,13 @@ class TestCliWesRunsCommand(unittest.TestCase):
             ],
         )
 
-        result_objects = json.loads(result.output)
+        self.assertEqual(
+            result.exit_code,
+            0,
+            msg=f"wes runs execute failed with code {result.exit_code} ({result.output})",
+        )
 
-        self.assertEqual(result.exit_code, 0)
+        result_objects = json.loads(result.output)
         assert_has_property(self, result_objects, "run_id")
 
         os.remove(wdl_file_path)
